@@ -54,6 +54,7 @@
 #include <kurlcompletion.h>
 #include <kurlpixmapprovider.h>
 #include <kfilewidget.h>
+#include <KFileUtils>
 
 #include "kfiletreeview_p.h"
 #include <kfileplacesview.h>
@@ -131,7 +132,7 @@ void KDirSelectDialog::Private::slotMkdir()
     QString where = m_parent->url().toDisplayString(QUrl::PreferLocalFile);
     QString name = i18nc("folder name", "New Folder");
     if (m_parent->url().isLocalFile() && QFileInfo::exists(m_parent->url().toLocalFile() + QLatin1Char('/') + name)) {
-        name = KIO::suggestName(m_parent->url(), name);
+        name = KFileUtils::suggestName(m_parent->url(), name);
     }
 
     QString directory = KIO::encodeFileName(QInputDialog::getText(m_parent, i18nc("@title:window", "New Folder"),
@@ -297,7 +298,7 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     m_buttons->addButton(folderButton, QDialogButtonBox::ActionRole);
     m_buttons->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     connect(m_buttons, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(m_buttons, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(m_buttons, &QDialogButtonBox::rejected, this, &QDialog::reject);
     topLayout->addWidget(m_buttons);
 
     QHBoxLayout *hlay = new QHBoxLayout(page);
@@ -310,8 +311,8 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     d->m_placesView->setObjectName(QStringLiteral("speedbar"));
     d->m_placesView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     d->m_placesView->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
-    connect(d->m_placesView, SIGNAL(urlChanged(QUrl)),
-            SLOT(setCurrentUrl(QUrl)));
+    connect(d->m_placesView, &KFilePlacesView::urlChanged,
+            this, &KDirSelectDialog::setCurrentUrl);
     hlay->addWidget(d->m_placesView);
     hlay->addLayout(mainLayout);
 
@@ -327,7 +328,9 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     d->m_urlCombo->setLayoutDirection(Qt::LeftToRight);
     d->m_urlCombo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
     d->m_urlCombo->setTrapReturnKey(true);
-    d->m_urlCombo->setPixmapProvider(new KUrlPixmapProvider());
+    d->m_urlCombo->setIconProvider([](const QString &name) {
+        return QIcon::fromTheme(KIO::iconNameForUrl(QUrl::fromUserInput(name)));
+    });
     KUrlCompletion *comp = new KUrlCompletion();
     comp->setMode(KUrlCompletion::DirCompletion);
     d->m_urlCombo->setCompletionObject(comp, true);
@@ -362,7 +365,7 @@ KDirSelectDialog::KDirSelectDialog(const QUrl &startDir, bool localOnly, QWidget
     d->showHiddenFoldersAction = new KToggleAction(i18nc("@option:check", "Show Hidden Folders"), this);
     d->m_actions->addAction(d->showHiddenFoldersAction->objectName(), d->showHiddenFoldersAction);
     d->showHiddenFoldersAction->setShortcut(Qt::Key_F8);
-    connect(d->showHiddenFoldersAction, SIGNAL(triggered(bool)), d->m_treeView, SLOT(setShowHiddenFiles(bool)));
+    connect(d->showHiddenFoldersAction, &QAction::triggered, d->m_treeView, &KFileTreeView::setShowHiddenFiles);
     d->m_contextMenu->addAction(d->showHiddenFoldersAction);
     d->m_contextMenu->addSeparator();
 
